#include <fstream>
#include <cstdio>
#include <cstring>
using namespace std;

const int N = 3e7, Sigma = 256;

char text[1 + N], pattern[1 + N], ans[1 + N], left_ans[1 + N], right_ans[1 + N];
int need[Sigma], skip[Sigma], ans_size;

inline bool is_smaller(char a, char b){
	return a < b;
}

inline bool is_bigger(char a, char b){
	return a > b;
}

inline void addTo(char* ans, int& size, char c){
	ans[size++] = c;
	need[c]--;
}

inline bool popChr(char c){
	if ( !skip[c] )
		return false;

	skip[c]--;
	need[c]++;

	return true;
}

bool set_need_skip(char* text, char* pattern){
	memset( need, 0, sizeof(need) );
	memset( skip, 0, sizeof(skip) );

	for (int i = 0; text[i]; i++)
		skip[ text[i] ]++;
	for (int i = 0; pattern[i]; i++)
		if ( !popChr( pattern[i] ) )
			return false;
	return true;
}

void match_prefix(int& st, int& dr){	//match as much as possible from original string
	ans_size = 0;
	if ( !set_need_skip(text, pattern) ){
		ans_size = -1;
		return;
	}

	int p, last = -1;
	for (p = 0; text[p] && pattern[ans_size]; p++)
		if ( text[p] == pattern[ans_size] ){
			addTo(ans, ans_size, text[p]);
			last = p;
		} else {
			skip[ text[p] ]--;
			if ( skip[ text[p] ] == -1 )
				break;
		}
	ans[ ans_size ] = '\0';

	if ( pattern[ans_size] ){
		st = last + 1;
		dr = p;
		while ( p != last)
			skip[ text[p--] ]++;
	} else
		st = dr = -1;
}

bool is_closer(char* L, char* v, char* R){
	for (int i = 0; v[i]; i++){
		int a = abs( L[i] - v[i] ), b = abs( R[i] - v[i] );
		if ( a != b )
			return a < b;
	}
	return true;
}

template< bool(*is_better)(char, char) >
void build_next(char* ans, int pos){
	if ( pos == -1 )
		return;

	set_need_skip(text + pos, pattern + ans_size);

//	cerr << "\t" << text + pos << '\n';
//	cerr << "\t" << pattern + ans_size << '\n';

	int size = 0;
	addTo(ans, size, text[pos]);
/*
	for (char c = 'a'; c <= 'z'; c++)
		if ( need[c] )
			cerr << c << ' ' << need[c] << ' ' << skip[c] << '\n';
*/
	for (int i = pos + 1; text[i]; i++){
		if ( !need[ text[i] ] ){
			skip[ text[i] ]--;
			continue;
		}
//		fprintf(stderr, "%c vs %c: %d, %d\n", is_better(text[i], ans[size])
		while ( size > 1 && is_better(text[i], ans[size-1]) && popChr( ans[size-1] ) )
			size--;
		addTo(ans, size, text[i]);
//		ans[size] = '\0';
//		cerr << ans << '\n';
	}
	ans[size] = '\0';
}

void sort_string(char* s){
	int cnt[Sigma] = {0};
	for (int i = 0; s[i]; i++)
		cnt[ s[i] ]++;
	for (int i = 0, j = 0; i < Sigma; i++)
		while ( cnt[i]-- )
			s[j++] = i;
}

int main(int argc, char** argv){
	if ( argc == 2 )
		freopen( argv[1], "r", stdin );

  ifstream in("password.in");
  ofstream out("password.out");

	in >> text >> pattern;
	sort_string(pattern);

	int st, dr;
	match_prefix(st, dr);		// first branching character must be picked from [st; dr]

	if ( ans_size == -1 ){
		out << "impossible\n";
		return 0;
	}

	if ( st == -1 ){			// matched entire pattern
		out << ans << '\n';
		return 0;
	}

	int best_min = -1, best_max = -1;
	for (int i = st; i <= dr; i++){
		if ( !need[ text[i] ] )
			continue;
		if ( text[i] < pattern[ ans_size ] ) {
			if ( best_min == -1 || text[best_min] < text[i] )
				best_min = i;
		} else {
			if ( best_max == -1 || text[i] < text[best_max] )
				best_max = i;
		}
	}

//	cerr << st << ' ' << dr << '\n';

	build_next<is_bigger> (left_ans,  best_min);
	build_next<is_smaller>(right_ans, best_max);

//	cerr << ans << '\n';
//	fprintf(stderr, "(%s) (%s)\n", left_ans, right_ans);

	if ( best_max == -1 || best_min != -1 && is_closer(left_ans, pattern + ans_size, right_ans) )
		strcat(ans, left_ans);
	else
		strcat(ans, right_ans);

	out << ans << '\n';

	return 0;
}
