// Method: Consider every symbol in S. Collect symbols in a stack in
// increasing order (so when we encounter a 10, first pop all the symbols of
// 11 or more from the stack, then push 10). For each distinct symbol,
// count:
//
// 1. how many we need (frequency in P)
// 2. how many we can afford to skip (frequency in S - value at step (1))
// 3. how many times we have it on the stack
//
// Then work greedily subject to these rules:
//
// * If symbol X already appears on the stack as many times as we need,
//   do not push it on the stack. Instead, skip it.
// * When skipping a symbol, decrease its "afford" counter.
// * When popping symbols from the stack, decrease their "afford" counter.
// * When X appears on the stack more times than we can afford to skip,
//   print the stack contents and empty the stack.
// * Special case: when the top of the stack contains K copy of the symbol X,
//   we only need to print one copy and keep the other K-1 copies.
//   For example, S = 2 2 2 1 2 2, P = 1 2 2 2
#include <deque>
#include <stdio.h>

#define MAX_LEN 30000000
#define MAX_CHAR 'z'

char s[MAX_LEN + 1], p[MAX_LEN + 1];
int need[MAX_CHAR + 1], afford[MAX_CHAR + 1], onstack[MAX_CHAR + 1];

// use a double ended queue, not a stack, due to the special case
std::deque<char> deq;

int main() {
  char *c;
  int i, top;

  FILE *f = fopen("password.in", "r");
  fscanf(f, "%s %s", s, p);
  fclose(f);

  f = fopen("password.out", "w");

  for (c = s; *c; c++) {
    afford[(int)*c]++;
  }
  for (c = p; *c; c++) {
    need[(int)*c]++;
    afford[(int)*c]--;
  }

  int possible = 1;
  for (i = 'a'; i <= 'z'; i++) {
    possible &= (afford[i] >= 0);
  }

  if (possible) {
    for (c = s; *c; c++) {
      if (onstack[(int)*c] < need[(int)*c]) {
        // pop larger elements from the stack...
        while (deq.size() && (deq.back() > *c)) {
          top = deq.back();
          deq.pop_back();
          onstack[top]--;
          afford[top]--;
        }
        // ... then push *c on the stack
        onstack[(int)*c]++;
        deq.push_back(*c);
      } else {
        // skip *c
        afford[(int)*c]--;
      }

      if (need[(int)*c] && (onstack[(int)*c] > afford[(int)*c])) {
        // print symbols smaller than *c and at most one copy of *c
        do {
          top = deq.front();
          deq.pop_front();
          fputc(top, f);
          onstack[top]--;
          need[top]--;
        } while (!deq.empty() && (top < *c));
      }
    }

    // print the remaining stack
    while (!deq.empty()) {
      fputc(deq.front(), f);
      deq.pop_front();
    }
    fputc('\n', f);
  } else {
    fprintf(f, "impossible\n");
  }
  
  fclose(f);
  return 0;
}
